@@ -2,7 +2,7 @@ import json
 import mimetypes
 from enum import Enum
 from pathlib import Path
-from typing import Dict, List, Optional, Union
+from typing import Optional, Union
 
 from attr import define
 from pydantic import BaseModel
@@ -34,13 +34,13 @@ class ConfigFile(BaseModel):
     See https://github.com/openapi-generators/openapi-python-client#configuration
     """
 
-    class_overrides: Optional[Dict[str, ClassOverride]] = None
-    content_type_overrides: Optional[Dict[str, str]] = None
+    class_overrides: Optional[dict[str, ClassOverride]] = None
+    content_type_overrides: Optional[dict[str, str]] = None
     project_name_override: Optional[str] = None
     package_name_override: Optional[str] = None
     package_version_override: Optional[str] = None
     use_path_prefixes_for_title_model_names: bool = True
-    post_hooks: Optional[List[str]] = None
+    post_hooks: Optional[list[str]] = None
     field_prefix: str = "field_"
     http_timeout: int = 5
     literal_enums: bool = False
@@ -63,18 +63,18 @@ class Config:
     """Contains all the config values for the generator, from files, defaults, and CLI arguments."""
 
     meta_type: MetaType
-    class_overrides: Dict[str, ClassOverride]
+    class_overrides: dict[str, ClassOverride]
     project_name_override: Optional[str]
     package_name_override: Optional[str]
     package_version_override: Optional[str]
     use_path_prefixes_for_title_model_names: bool
-    post_hooks: List[str]
+    post_hooks: list[str]
     field_prefix: str
     http_timeout: int
     literal_enums: bool
     document_source: Union[Path, str]
     file_encoding: str
-    content_type_overrides: Dict[str, str]
+    content_type_overrides: dict[str, str]
     overwrite: bool
     output_path: Optional[Path]
 
